<?php

namespace Drupal\layout_builder_tomsaw\Form;

use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Form\FormStateInterface;

/**
 * Form controller for the segment entity edit forms.
 */
class SegmentForm extends ContentEntityForm {

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    $result = parent::save($form, $form_state);

    $entity = $this->getEntity();

    $message_arguments = ['%title' => $entity->toLink()->toString()];
    $logger_arguments = [
      '%title' => $entity->label(),
      'link' => $entity->toLink($this->t('View'))->toString(),
    ];

    switch ($result) {
      case SAVED_NEW:
        $this->messenger()->addStatus($this->t('New segment %title has been created.', $message_arguments));
        $this->logger('layout_builder_tomsaw')->notice('Created new segment %title', $logger_arguments);
        break;

      case SAVED_UPDATED:
        $this->messenger()->addStatus($this->t('The segment %title has been updated.', $message_arguments));
        $this->logger('layout_builder_tomsaw')->notice('Updated segment %title.', $logger_arguments);
        break;
    }

    $form_state->setRedirect('entity.segment.canonical', ['segment' => $entity->id()]);

    return $result;
  }

}
