<?php

namespace Drupal\layout_builder_tomsaw;

use Drupal\ui_styles\StylePluginManager;

class StylePluginManagerRestricted extends StylePluginManager {
  const title_to_domain = [
    'Section styles' => 'style',
    'Block styles' => 'block',
    'Title styles' => 'title',
    'Content styles' => 'content',
    'Exposed form' => 'exposed_form',
    'Style' => 'style',
  ];

	const route_name_to_scope = [
		"layout_builder.configure_section" => 'section',
		"layout_builder.update_block" => 'block',
    "views_ui.form_display" => 'view'
	];

  protected string $domain;

	public function getDefinitions(): array {
		$definitions = parent::getDefinitions();

    $attributes = \Drupal::request()->attributes;
    $route_name = $attributes->get('_route');

		if (isset($this->domain) && key_exists($route_name, self::route_name_to_scope)) {
			$scope = self::route_name_to_scope[$route_name] . ':' . $this->domain;

      // Filter out restricted styles
      $definitions = array_filter($definitions, function ($definition) use ($scope) {
        $additional = $definition->getAdditional();
				if(!isset($additional['restriction'])) {
          return TRUE;
        }

        foreach($additional['restriction'] as $restriction) {
          if(str_starts_with($scope, $restriction)) {
            return TRUE;
          }
        }
        return FALSE;
			});
		}

		return $definitions;
	}


  /**
   * {@inheritdoc}
   */
  public function alterForm(array $form, array $selected = [], string $extra = '', string $theme = ''): array {
    // @todo MR solid code and remove this shabby hack:
    // Lookup title scope in forms #title
    // @see ui_styles_layout_builder.module ui_styles_layout_builder_form_alter()
    $title = (string) $form['#title'];

    if(!isset(self::title_to_domain[$title])) {
      throw new \InvalidArgumentException("Title '$title' is not in title_to_domain.");
    } else {
      $this->domain = self::title_to_domain[$title];
    }

    $form = parent::alterForm($form, $selected, $extra, $theme);

    // Another issue, but lets place it here for now
    $form['#open'] = TRUE;
    return $form;
  }
}
